HPZone_make_valid: Takes a list of fields or endpoints and corrects them. This...

HPZone_make_validR Documentation

Takes a list of fields or endpoints and corrects them. This allows for short hand usage without having to check the documentation, e.g. 'Date of onset' instead of 'Date_of_onset'

Description

Takes a list of fields or endpoints and corrects them. This allows for short hand usage without having to check the documentation, e.g. 'Date of onset' instead of 'Date_of_onset'

Usage

HPZone_make_valid(endpoints = NULL, fields = NULL)

Arguments

endpoints

A list of desired endpoints.

fields

A list of desired fields.

Value

A list of properly formatted fields or endpoints.

Examples

HPZone_make_valid("case") # should return "cases"
HPZone_make_valid(fields="case_creation") # should return "Case_creation_date"
HPZone_make_valid("case", fields=c("Family name", "Gp")) # should return c("Family_name", "Gp")

HPZoneAPI documentation built on April 9, 2026, 5:09 p.m.