HPZone_necessary_scope: Determines the necessary scope for a given list of fields.

HPZone_necessary_scopeR Documentation

Determines the necessary scope for a given list of fields.

Description

Determines the necessary scope for a given list of fields.

Usage

HPZone_necessary_scope(fields, endpoint = "Cases", resolve_fieldnames = TRUE)

Arguments

fields

List of desired fields from a query.

endpoint

The required endpoint.

resolve_fieldnames

Whether or not to parse the supplied fields and convert them to valid HPZone field names. (By calling [HPZone_make_valid])

Value

The required scope as expected by the HPZone API, i.e. "standard" or "extended".

Examples

# these variables do not required an extended scope; desired response = standard
HPZone_necessary_scope(c("Diagnosis", "Case_number", "Entered_by"))
# Family_name requires the extended scope; desired response = extended
HPZone_necessary_scope(c("Diagnosis", "Case_number", "Family_name"))

HPZoneAPI documentation built on April 9, 2026, 5:09 p.m.