| HPZone_setup | R Documentation |
Initialisation function to define API credentials. This function must be called before anything else, as the details supplied in this call are required for use. Note that client_id and client_secret should preferably not be supplied in this call, but rather stored using [HPZone_store_credentials()].
HPZone_setup(
client_id = NA,
client_secret = NA,
standard = "standard",
extended = "extended",
token_url = "https://connect.govconext.nl/oidc/token",
data_url = "https://api.hpzone.nl:8899/Edie"
)
client_id |
Client ID as supplied by InFact. |
client_secret |
Client secret as supplied by InFact. |
standard |
Name of the standard scope. Default: "standard" |
extended |
Name of the extended scope. Default: "extended" |
token_url |
Address of the token server. |
data_url |
Address of the data server. |
No return value.
# Not recommended:
HPZone_setup("id", "secret")
# Recommended:
## Not run:
HPZone_store_credentials() # call once
HPZone_setup() # will automatically read stored credentials
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.