HPZone_store_credentials: Safely stores the HPZone API details, so you don't need to...

HPZone_store_credentialsR Documentation

Safely stores the HPZone API details, so you don't need to put them in your script. The default OS keyring backend is used through the keyring-package. Values are stored in an encrypted format to prevent harvesting by other applications. Note that the actual values are not supplied as arguments, but requested using rstudioapi password prompts.

Description

Safely stores the HPZone API details, so you don't need to put them in your script. The default OS keyring backend is used through the keyring-package. Values are stored in an encrypted format to prevent harvesting by other applications. Note that the actual values are not supplied as arguments, but requested using rstudioapi password prompts.

Usage

HPZone_store_credentials(client_id = TRUE, client_secret = TRUE)

Arguments

client_id

True / false: whether the client_id should be stored.

client_secret

True / false: whether the client_secret should be stored.

Value

N/A

Examples

## Not run: 
# simply execute this line to store credentials
HPZone_store_credentials()
# after use, setup can be ran without arguments:
HPZone_setup()

## End(Not run)

HPZoneAPI documentation built on April 9, 2026, 5:09 p.m.