test_HPZone_token: Tests the supplied HPZone token against the token endpoint....

test_HPZone_tokenR Documentation

Tests the supplied HPZone token against the token endpoint. Note that this does not check the type of access, only the functionality of the token.

Description

Tests the supplied HPZone token against the token endpoint. Note that this does not check the type of access, only the functionality of the token.

Usage

test_HPZone_token()

Value

No return value.

Examples

## Not run: 
HPZone_setup()
# This will print the results.
test_HPZone_token()

## End(Not run)

HPZoneAPI documentation built on April 9, 2026, 5:09 p.m.