| HPZone_make_valid | R Documentation |
Takes a list of fields or endpoints and corrects them. This allows for short hand usage without having to check the documentation, e.g. 'Date of onset' instead of 'Date_of_onset'
HPZone_make_valid(endpoints = NULL, fields = NULL)
endpoints |
A list of desired endpoints. |
fields |
A list of desired fields. |
A list of properly formatted fields or endpoints.
HPZone_make_valid("case") # should return "cases"
HPZone_make_valid(fields="case_creation") # should return "Case_creation_date"
HPZone_make_valid("case", fields=c("Family name", "Gp")) # should return c("Family_name", "Gp")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.