| HPZone_store_credentials | R Documentation |
Safely stores the HPZone API details, so you don't need to put them in your script. The default OS keyring backend is used through the keyring-package. Values are stored in an encrypted format to prevent harvesting by other applications. Note that the actual values are not supplied as arguments, but requested using rstudioapi password prompts.
HPZone_store_credentials(client_id = TRUE, client_secret = TRUE)
client_id |
True / false: whether the client_id should be stored. |
client_secret |
True / false: whether the client_secret should be stored. |
N/A
## Not run:
# simply execute this line to store credentials
HPZone_store_credentials()
# after use, setup can be ran without arguments:
HPZone_setup()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.